"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SheetExcelCreator = void 0;
const excelCreatorCustomizer_1 = require("./excelCreatorCustomizer");
const constants_1 = require("../constants");
class SheetExcelCreator {
    create({ name, items, structures, }) {
        const buildedSheetData = this.buildSheetData(items, structures);
        const buildedOptions = this.buildOptions(structures);
        const sheetBuilder = this.buildSheetBuilder(name, buildedSheetData, buildedOptions);
        return sheetBuilder;
    }
    buildSheetBuilder(name, data, options) {
        const sheetBuilder = { name, data, options };
        return sheetBuilder;
    }
    buildSheetData(items, structures) {
        const buildedItems = [];
        const buildedTitleSheet = [
            structures.map((struct) => struct.header.displayName),
        ];
        const buildedItemSheet = items.map((item) => structures.map((struct) => this.customItem(struct, item)));
        const buildedSheet = buildedItems.concat(buildedTitleSheet, buildedItemSheet);
        return buildedSheet;
    }
    customItem(struct, item) {
        const { id, custom: itemCustom } = struct;
        const itemField = item[id];
        if (!this.checkValidItem(itemField))
            return constants_1.ITEM_DEFAULT;
        const customElement = new excelCreatorCustomizer_1.ExcelCreatorCustomizer().custom(itemField, itemCustom);
        return customElement;
    }
    buildOptions(structures) {
        const buildedColumnStyle = structures.map((struct) => ({
            width: struct.width,
        }));
        const options = { ["!cols"]: buildedColumnStyle };
        return options;
    }
    checkValidItem(item) {
        return ![null, undefined, ""].includes(item);
    }
}
exports.SheetExcelCreator = SheetExcelCreator;
